/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 16:28:20.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.entity;

import cn.afterturn.easypoi.excel.annotation.Excel;
import cn.com.qmth.examcloud.core.print.common.IdEntity;
import cn.com.qmth.examcloud.core.print.enums.QuesStructType;

import javax.persistence.*;
import java.util.Map;

/**
 * 客观题信息(用于Excel导出)
 */
@Entity
@Table(name = "ec_prt_objective_question_structure", indexes = {
        @Index(name = "INDEX_PRT_OBJECTIVE_QUESTION_01", columnList = "examId"),
        @Index(name = "INDEX_PRT_OBJECTIVE_QUESTION_02", columnList = "courseId"),
        @Index(name = "INDEX_PRT_OBJECTIVE_QUESTION_03", columnList = "paperId")})
public class ObjectiveQuestionStructure extends IdEntity {
    /**
     * 考试ID
     */
    private Long examId;
    /**
     * 课程ID
     */
    private Long courseId;
    /**
     * 课程代码
     */
    @Excel(name = "课程代码", orderNum = "0")
    @Column(length = 50)
    private String courseCode;
    /**
     * 课程名称
     */
    @Excel(name = "课程名称", orderNum = "1")
    @Column(length = 50)
    private String courseName;
    /**
     * 试卷ID
     */
    @Column(length = 50)
    private String paperId;
    /**
     * 试卷名称
     */
    @Excel(name = "试卷名称", orderNum = "2")
    @Column(length = 100)
    private String paperName;
    /**
     * 大题号
     */
    @Excel(name = "大题号", orderNum = "4")
    private Integer sectionNum;
    /**
     * 小题号
     */
    @Excel(name = "小题号", orderNum = "5")
    private Integer unitNum;
    /**
     * 小题分数
     */
    @Excel(name = "小题分数", orderNum = "8")
    private Double unitScore;
    /**
     * 标准答案
     */
    @Excel(name = "标准答案", orderNum = "7")
    @Column(length = 50)
    private String answer;
    /**
     * 试题类型
     *
     * @See QuesStructType.java
     */
    @Excel(name = "题目类型", orderNum = "6")
    @Column(length = 50)
    private String questionType;
    /**
     * 试卷类型(如：A、B)
     * 该字段不持久化到数据库
     */
    @Excel(name = "试卷类型", orderNum = "3")
    @Transient
    private String paperType;

    public ObjectiveQuestionStructure(QuesStructType questionType, Map<String, String> properties) {
        this.courseCode = properties.get("courseCode");
        this.courseName = properties.get("courseName");
        this.paperName = properties.get("paperName");
        this.paperType = properties.get("paperType");
        this.questionType = questionType.getTitle();
        this.sectionNum = questionType.getId();
        this.unitNum = 0;
        this.unitScore = 0D;
        this.answer = "#";
    }

    public ObjectiveQuestionStructure() {

    }

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public String getCourseCode() {
        return courseCode;
    }

    public void setCourseCode(String courseCode) {
        this.courseCode = courseCode;
    }

    public String getCourseName() {
        return courseName;
    }

    public void setCourseName(String courseName) {
        this.courseName = courseName;
    }

    public String getPaperId() {
        return paperId;
    }

    public void setPaperId(String paperId) {
        this.paperId = paperId;
    }

    public String getPaperName() {
        return paperName;
    }

    public void setPaperName(String paperName) {
        this.paperName = paperName;
    }

    public Integer getSectionNum() {
        return sectionNum;
    }

    public void setSectionNum(Integer sectionNum) {
        this.sectionNum = sectionNum;
    }

    public Integer getUnitNum() {
        return unitNum;
    }

    public void setUnitNum(Integer unitNum) {
        this.unitNum = unitNum;
    }

    public Double getUnitScore() {
        return unitScore;
    }

    public void setUnitScore(Double unitScore) {
        this.unitScore = unitScore;
    }

    public String getAnswer() {
        return answer;
    }

    public void setAnswer(String answer) {
        this.answer = answer;
    }

    public String getQuestionType() {
        return questionType;
    }

    public void setQuestionType(String questionType) {
        this.questionType = questionType;
    }

    public String getPaperType() {
        return paperType;
    }

    public void setPaperType(String paperType) {
        this.paperType = paperType;
    }

}