/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-13 16:34:46.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.api.controller;

import cn.com.qmth.examcloud.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.common.Result;
import cn.com.qmth.examcloud.core.print.service.CoursePaperService;
import cn.com.qmth.examcloud.core.print.service.ExamStructureService;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.File;
import java.util.List;

import static cn.com.qmth.examcloud.core.print.common.Constants.STRUCT_ZIP_NAME;
import static cn.com.qmth.examcloud.core.print.common.Result.success;

/**
 * 课程试卷相关接口
 *
 * @author: fengdesheng
 * @since: 2018/11/13
 */
@RestController
@Api(tags = "课程试卷相关接口")
@RequestMapping("${$rmp.ctrl.print}/course/paper")
public class CoursePaperController extends ControllerSupport {
    @Autowired
    private CoursePaperService coursePaperService;
    @Autowired
    private ExamStructureService examStructureService;

    @PostMapping("/list")
    @ApiOperation(value = "获取课程试卷列表")
    public List<CoursePaperLessInfo> list(@RequestBody CoursePaperQuery query) {
        return coursePaperService.getCoursePaperList(query);
    }

    @PostMapping("/allot/{courseStatisticId}/{coursePaperId}")
    @ApiOperation(value = "(单个)分配待指定试卷")
    public Result allotCoursePaper(@PathVariable Long courseStatisticId, @PathVariable Long coursePaperId) {
        coursePaperService.allotCoursePaper(courseStatisticId, coursePaperId);
        return success();
    }

    @PostMapping("/allot/all/{orgId}/{examId}")
    @ApiOperation(value = "(整体)分配待指定试卷")
    public Result allotAllCoursePaper(@PathVariable Long orgId, @PathVariable Long examId) {
        coursePaperService.allotAllCoursePaper(orgId, examId);
        return success();
    }

    @PostMapping("/total/{orgId}/{examId}")
    @ApiOperation(value = "获取某学校考试的试卷数量情况")
    public CoursePaperTotalInfo paperTotal(@PathVariable Long orgId, @PathVariable Long examId) {
        return coursePaperService.getPaperTotalByOrgIdAndExamId(orgId, examId);
    }

    @PostMapping("/check/structure/{orgId}/{examId}/{paperId}")
    @ApiOperation(value = "校验考试试卷结构")
    public Result checkPaperStructure(@PathVariable Long orgId, @PathVariable Long examId, @PathVariable String paperId) {
        examStructureService.checkExamStructure(orgId, examId, paperId);
        return success();
    }

    @GetMapping("/export/batch")
    @ApiOperation(value = "批量导出")
    public void exportBatch(@RequestParam Long[] ids, @RequestParam Integer[] types) {
        ExportBatchReq req = new ExportBatchReq(ids, types);
        File file = coursePaperService.exportBatchCoursePaper(req);
        if (file != null) {
            super.exportFile(STRUCT_ZIP_NAME, file);
        } else {
            super.exportFile(STRUCT_ZIP_NAME, new byte[]{});
        }
    }

    @GetMapping("/export/all")
    @ApiOperation(value = "整体导出")
    public void exportAll(@RequestParam Long orgId, @RequestParam Long examId, @RequestParam Integer[] types) {
        ExportAllReq req = new ExportAllReq(orgId, examId, types);
        File file = coursePaperService.exportAllCoursePaper(req);
        if (file != null) {
            super.exportFile(STRUCT_ZIP_NAME, file);
        } else {
            super.exportFile(STRUCT_ZIP_NAME, new byte[]{});
        }
    }

}